Aydin Denoising of Spinning-Disk Confocal Images of Zebrafish Embryos from Royer Lab (CZ Biohub, San Francisco)
================================================================================================================


.. raw:: html

   <iframe src="https://docs.google.com/document/d/e/2PACX-1vThcNzLy5_VjaH3wBCmvujtnjPOtjjsrFqWb2AW_hOPrB30WWLp4FdA_NhnWxDJdxpmFKl2_Qtf1mgS/pub?embedded=true" height="2880" width="720"></iframe>

